#
# spec file for package jose
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 0

Name:           jose
Version:        13
Release:        1.3
Summary:        C-language implementation of Javascript Object Signing and Encryption
License:        Apache-2.0
URL:            https://github.com/latchset/jose
Source0:        https://github.com/latchset/jose/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  asciidoc
BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(jansson) >= 2.10
BuildRequires:  pkgconfig(libcrypto) >= 1.0.2
BuildRequires:  pkgconfig(zlib)

%description
José is a C-language implementation of the Javascript Object Signing and Encryption standards.

%package -n lib%{name}%{so_ver}
Summary:        C-language implementation of Javascript Object Signing and Encryption

%description -n lib%{name}%{so_ver}
José is a C-language implementation of the Javascript Object Signing and Encryption standards.

%package -n lib%{name}-devel
Summary:        Development files for lib%{name}
Requires:       lib%{name}%{so_ver} = %{version}
Requires:       pkgconfig(jansson) >= 2.10
Requires:       pkgconfig(libcrypto) >= 1.0.2

%description -n lib%{name}-devel
The lib%{name}-devel package contains libraries and header files for
developing applications that use lib%{name}.

%check

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%post -n lib%{name}%{so_ver} -p /sbin/ldconfig
%postun -n lib%{name}%{so_ver} -p /sbin/ldconfig

%files
%license COPYING
%{_bindir}/*
%{_mandir}/man1/*

%files -n lib%{name}%{so_ver}
%license COPYING
%{_libdir}/*.so.*
%{_mandir}/man3/*

%files -n lib%{name}-devel
%license COPYING
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%changelog
* Tue Apr 16 2024 ming li <mli@suse.com>
- Update to version 13:
  * Fix potential DoS issue with p2c header (4ee7708)
  * Build updates (#148) (dae5654)
  * Display pkg_config in test logs (#134) (5e45732)
* Fri Mar  8 2024 jun wang <jgwang@suse.com>
- Update to version 12
  * Clean up some FreeBSD conditions (#98)
  * Add ES256K support (#90)
  * Meson changes (#135)
  * Update CI (#8) (#129)
  * lib/openssl/rsaes.c: Fix issue where jose_hook_alg_find
    failed to find the … …existance of RSA_OAEP algorithm
  * Increase test program/scripts timeout values (#131)
  * Fix test compilation warnings (#127)
  * Adapt alg_comp test to different zlib (#142)
  * Use checkout v3 Github action to avoid warnings (#137)
  * Alternative fix for fedora:rawide (#138)
  * lib/openssl/hmac.c: rename hmac function to jhmac (#130)
  * jose: build library only as shared (#119)
  * meson: add option to disable building manpages (#118)
  * Add a more descriptive error when jwk gen fails (#105)
  * Use "command -v" instead of "which" (deprecated) (#125)
  * Test for jq existing (used in jose-jwe-enc test) (#124)
  * Correct jose_jws.3 man page example (#122)
  * lib/hsh.c: rename hsh local variable (#111)
  * Avoid master word when possible (#120)
  * Fix github action CI by setting appropriate centos
  * Fix format of jose-jwe-enc man page
  * Meson Fixes
  * ci: make ubuntu:devel and fedora:rawhide not to fail the
    pipeline
  * ci: retry when installing the deps in debian/ubuntu
  * ci: remove travis-ci
* Tue Apr 11 2023 Marcus Meissner <meissner@suse.com>
- initial import of C-language implementation of Javascript Object
  Signing and Encryption, for use by clevis
